@@ -19,7 +19,7 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
-const { Clutter, Meta, Shell, St } = imports.gi;
+const {Clutter, Meta, Shell, St} = imports.gi;
 
 const ExtensionUtils = imports.misc.extensionUtils;
 const Main = imports.ui.main;
@@ -39,7 +39,7 @@ function hideMessage() {
  */
 function flashMessage(message) {
     if (!text) {
-        text = new St.Label({ style_class: 'screenshot-sizer-message' });
+        text = new St.Label({style_class: 'screenshot-sizer-message'});
         Main.uiGroup.add_actor(text);
     }
 
@@ -101,10 +101,6 @@ function cycleScreenshotSizes(display, window, binding) {
     for (let i = 0; i < scaledSizes.length; i++) {
         let [width, height] = scaledSizes[i];
 
-        // ignore sizes bigger than the workArea
-        if (width > workArea.width || height > workArea.height)
-            continue;
-
         // get the best initial window size
         let error = Math.abs(width - outerRect.width) + Math.abs(height - outerRect.height);
         if (nearestIndex === undefined || error < nearestError) {
@@ -125,8 +121,18 @@ function cycleScreenshotSizes(display, window, binding) {
     if (newY + newHeight > workArea.y + workArea.height)
         newY = Math.max(workArea.y + workArea.height - newHeight);
 
+    const id = window.connect('size-changed', () => {
+        window.disconnect(id);
+        _notifySizeChange(window);
+    });
     window.move_resize_frame(true, newX, newY, newWidth, newHeight);
+}
 
+/**
+ * @param {Meta.Window} window - the window whose size changed
+ */
+function _notifySizeChange(window) {
+    const {scaleFactor} = St.ThemeContext.get_for_stage(global.stage);
     let newOuterRect = window.get_frame_rect();
     let message = '%d×%d'.format(
         newOuterRect.width / scaleFactor,
